CellarDoor
=======

|Build Status| |Coverage Status|

CellarDoor is a framework for building CRUD APIs mostly declaratively. It includes data modeling, data storage, authentication, authorization, serialization and interface protocols. It aims to dramatically reduce repetitive effort without getting in the way of the interesting bits of your application.


.. |Build Status| image:: https://travis-ci.org/cooper-software/cellardoor.svg
   :target: https://travis-ci.org/cooper-software/cellardoor

.. |Coverage Status| image:: https://img.shields.io/coveralls/cooper-software/cellardoor.svg
   :target: https://coveralls.io/r/cooper-software/cellardoor
